"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const execa_1 = __importDefault(require("execa"));
const tmux_1 = require("./tmux");
const iterm_1 = require("./iterm");
exports.mac = (execFilePath, options) => {
    const { terminalApp, split } = options;
    const isIterm = ["iTerm", "iTerm.app", "iTerm2", "iTerm2.app"].includes(terminalApp);
    const isTmux = !!process.env.TMUX_PANE;
    try {
        if (isTmux && split) {
            return tmux_1.tmux(execFilePath, options);
        }
        if (isIterm && split) {
            return iterm_1.iterm(execFilePath, options);
        }
        // When running from VSCode/Apple_Terminal It's better to verify that
        // we run the command using the Terminal.app
        if (!options.terminalApp ||
            ["vscode", "Apple_Terminal"].includes(options.terminalApp)) {
            options.terminalApp = "Terminal";
        }
        execa_1.default.sync("open", ["-a", options.terminalApp, execFilePath]);
    }
    catch (error) {
        execa_1.default.sync("open", [execFilePath]);
    }
};
//# sourceMappingURL=mac.js.map